@@ -86,6 +86,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 展示策略错误。
 INVALIDPARAMETER_DISPLAYSTRATEGYNOTMATCH = 'InvalidParameter.DisplayStrategyNotMatch'
 
+# 参数错误。
+INVALIDPARAMETER_HALESSMASTERCOUNT = 'InvalidParameter.HALessMasterCount'
+
 # Common节点数量无效。
 INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'
 
@@ -146,6 +149,9 @@ INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'
 # 无效的集群保留策略。
 INVALIDPARAMETER_INVALIDINSTANCEPOLICY = 'InvalidParameter.InvalidInstancePolicy'
 
+# 无效的机型。
+INVALIDPARAMETER_INVALIDINSTANCETYPE = 'InvalidParameter.InvalidInstanceType'
+
 # 无效的流程任务。
 INVALIDPARAMETER_INVALIDJOBFLOW = 'InvalidParameter.InvalidJobFlow'
 
